/*
 * Created by sweetbread on 21.02.2025, 12:08
 * Copyright (c) 2025. All rights reserved.
 * Last modified 21.02.2025, 12:08
 */

package ru.risdeveau.pixeldragon.ui.activity

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Scaffold
import androidx.compose.material3.SnackbarDuration
import androidx.compose.material3.SnackbarHost
import androidx.compose.material3.SnackbarHostState
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.unit.dp
import kotlinx.coroutines.launch
import ru.risdeveau.pixeldragon.api.isMatrixServer
import ru.risdeveau.pixeldragon.api.login
import ru.risdeveau.pixeldragon.ui.theme.PixelDragonTheme
import splitties.activities.start

class Login : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            PixelDragonTheme {
                Surface {
                    val snackbarHostState = remember { SnackbarHostState() }
                    val scope = rememberCoroutineScope()

                    Scaffold (
                        snackbarHost = {
                            SnackbarHost(hostState = snackbarHostState)
                        }
                    ) { innerPadding ->
                        Box(Modifier.fillMaxSize().padding(innerPadding)) {
                            LoginField(
                                Modifier.align(Alignment.Center),
                                { start<MainActivity>() },
                                {
                                    scope.launch {
                                        snackbarHostState
                                            .showSnackbar(
                                                message = "Login failed",
                                                duration = SnackbarDuration.Long
                                            )
                                    }
                                }
                            )
                        }
                    }
                }
            }
        }
    }
}

@Composable
fun LoginField(modifier: Modifier = Modifier, ok: () -> Unit, err: () -> Unit) {
    Column (
        modifier = modifier
    ) {
        val scope = rememberCoroutineScope()

        var homeserver by remember { mutableStateOf("") }
        var login by remember { mutableStateOf("") }
        var pass by remember { mutableStateOf("") }

        var hmsValid by remember { mutableStateOf(false) }

        OutlinedTextField(
            modifier = Modifier.padding(4.dp),
            value = homeserver,
            onValueChange = { homeserver = it.trim() },
            label = { Text("Homeserver") },
            placeholder = { Text("matrix.org") },
            singleLine = true,
            isError = !hmsValid
        )
        OutlinedTextField(
            modifier = Modifier.padding(4.dp),
            value = login,
            onValueChange = { login = it.trim() },
            label = { Text("Login") },
            singleLine = true
        )
        OutlinedTextField(
            modifier = Modifier.padding(4.dp),
            value = pass,
            onValueChange = { pass = it.trim() },
            label = { Text("Password") },
            visualTransformation = PasswordVisualTransformation(),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Password),
            singleLine = true,
        )
        Button(
            enabled = hmsValid && !login.isEmpty() && !pass.isEmpty(),
            onClick = {
                var loginSuccess = false
                scope.launch { loginSuccess = login(homeserver, login, pass) }

                if (loginSuccess) ok()
                else err()
            }
        ) {
            Text("Login")
        }

        LaunchedEffect(homeserver) {
            scope.launch { hmsValid = isMatrixServer(homeserver) }
        }
    }
}